@@ -14,6 +14,7 @@
 #' @param k is a vector of country of region names
 #' @param i is a vector of sector or industry names
 #' @param o is a vecotr of final outputs
+#' @param null_inventory when the inventory (last FDC) should be set to zero
 #' @return a decompr class object
 #' @author Bastiaan Quast
 #' @details Adapted from code by Fei Wang.
@@ -33,13 +34,13 @@
 #' str(decompr_object)
 
 
-load_tables_vectors <- function(x, y, k, i, o) {
+load_tables_vectors <- function(x, y, k, i, o, null_inventory = FALSE ) {
 
   # find number of sections and regions
   # compute combination
   G      <- length(k)
   N      <- length(i)
-  GN     <- G * N
+  GN     <- G * N  
   
   # create vector of unique combinations of regions and sectors
   z <- t(outer(k, i, paste, sep="."))
@@ -52,6 +53,14 @@ load_tables_vectors <- function(x, y, k, i, o) {
   
   bigrownam <- paste( z01, z02, sep="." )
   
+    # contruct final demand components
+  fdc <- dim(y)[2] / G
+  
+  # null inventory if needed
+  if (null_inventory==TRUE) {
+    y[ , fdc*(1:G) ] <- 0
+  }
+  
   # define dimensions
   Ad   <- matrix( 0, nrow = GN, ncol = GN )
   Am   <- Ad
@@ -94,10 +103,6 @@ load_tables_vectors <- function(x, y, k, i, o) {
   
   Vhat <- diag(Vc)
   
-  
-  # contruct final demand components
-  fdc <- dim(y)[2] / G
-  
   # Part 2: computing final demand: Y
   for ( j in 1:G ){
     m <- 1   + (j-1) * fdc
@@ -177,8 +182,8 @@ load_tables_vectors <- function(x, y, k, i, o) {
   rownames( ESR ) <- rownam
   dimnames(Eint)  <- dimnames( ESR )
   dimnames(Efd)   <- dimnames( ESR )
-  
 
+  
   # Part 5: creating decompr object
   out <- list( Exp  = Exp,
                Vhat = Vhat,
